import { useEffect, useState } from 'react';
import { useSelector } from 'react-redux'
import { Table, Modal, message, Menu, Breadcrumb, Dropdown, Space, Form, Input, Button, Row, Col, Select } from 'antd';
import { DownOutlined, PlusOutlined } from '@ant-design/icons';
import './index.less';
import apiObj from '@api/index';
import utils from '@utils/index'
const { post, api, xPost } = apiObj;
const { Option } = Select;
function UserList() {
    useEffect(() => {
        //刷新列表
        getTableData();

    }, []);

    const [size, setSize] = useState(15);       //每页显示条数
    const [total, setTotal] = useState(0);       //每页显示条数
    const [dataSource, setDataSource] = useState([]);   //列表数据
    //从state中取出状态、类型列表
    const staticInfo = useSelector(state => {
        return state.staticInfo;
    });
    const { msgTypeList, msgStatusList } = staticInfo;

    //获取表格数据
    function getTableData(param = {}) {
        post(api.getHospitalUser, param).then((res) => {
            if (res.data.code === 200) {
                let data = res.data.data;
                setTotal(data.total);
                setDataSource(data.records);
            }

        })
    }
    //每页显示条数切换
    function onSizeChange(){

    }
    //翻页
    function onPageChange(){

    }
    //表格渲染
    function RenderTable() {
        const columns = [
            { title: '全选',width:60, dataIndex: 'title', key: 'title' },
            { title: '姓名', dataIndex: 'name', key:'name'},
            { title: '电话号码', dataIndex: 'mobilePhone', key: 'mobilePhone' },
            { title: '所属组织', dataIndex: 'hospitalName', key: 'hospitalName' },
        ];
        const rowSelection = {
            onChange:()=>{}
        };
        return (
            <Table
                rowSelection={rowSelection}
                rowKey={record => record.id}
                columns={columns}
                dataSource={dataSource}
                pagination={{
                    showSizeChanger:true,
                    pageSizeOptions:[15,30,60,120],
                    defaultPageSize:size,
                    pageNo: 1,
                    size:'small',
                    total: total,
                    showTotal: (total, range) => `第${range[0]}-${range[1]} 条/共 ${total} 条数据`,
                }}
            />
        )

    }
    //筛选项渲染
    const [form] = Form.useForm();
    const onFinish = (values: any) => {
        getTableData(values);
        console.log('筛选项:', values);
    };
    const onReset = () => {
        form.resetFields();
        getTableData();
    };
    return (
        <div className='wrapper'>
            <div className="filter-box">
                <Form form={form} name="control-hooks" onFinish={onFinish}>
                    <Row gutter={24}>
                        <Col span={5} key={1}>
                            <Form.Item name="type" label="姓名">
                                <Input placeholder='姓名'/>
                            </Form.Item>
                        </Col>
                        <Col span={5} key={2}>
                            <Form.Item name="type" label="手机号码">
                                <Input placeholder='手机号码'/>
                            </Form.Item>
                        </Col>
                        <Col span={5} key={3}>
                            <Form.Item name="status" label="所属组织">
                                <Select
                                    allowClear
                                >
                                    {msgStatusList.map((item) => {
                                        return (
                                            <Option value={item.name} key={item.name}>{item.val}</Option>
                                        )
                                    })}
                                </Select>
                            </Form.Item>
                        </Col>
                        <Col span={9} key={4}>
                            <Form.Item>
                                <Button type="primary" htmlType="submit">
                                    查询
                                </Button>
                                <Button htmlType="button" onClick={onReset}>
                                    重置
                                </Button>
                            </Form.Item>
                        </Col>
                    </Row>
                </Form>
            </div>
            <div className="table">
                <div className="table-header">
                    <h2 className="table-title">用户列表</h2>
                </div>
                <RenderTable />
            </div>
        </div>
    )
}

export default UserList;